@@ -42,6 +42,10 @@ class NoFastTraceWarning(UserWarning):
     pass
 
 
+class SkipTypeCheck(UserWarning):
+    pass
+
+
 ConfigValue = Args
 ConfigKey = collections.abc.Callable
 Config = typing.Dict[ConfigKey, ConfigValue]
@@ -53,6 +57,8 @@ _get_func_and_arg_cache: dict[
     tuple[ConfigKey, str],
 ] = {}
 _fast_trace_enabled: bool = False
+# NOTE: These names are unique so they don't interfere with existing attributes.
+_orginal_key = "___orginal_key"
 
 
 class KeyErrorMessage(str):
@@ -271,6 +277,7 @@ def purge():
         warnings.warn(message, UnusedConfigsWarning)
 
     [unset_trace(f) for f, _ in _get_funcs_to_trace(_config)]
+    [delattr(k, _orginal_key) for k in _config.keys() if hasattr(k, _orginal_key)]
     _config = {}
     _code_to_func = {}
     _call_once.cache_clear()
@@ -285,22 +292,42 @@ def export() -> Config:
 
     NOTE: It would be an anti-pattern to use this for configuring functions.
     """
-    return {k: v.copy() for k, v in _config.items()}
+    return {
+        getattr(k, _orginal_key) if hasattr(k, _orginal_key) else k: v.copy()
+        for k, v in _config.items()
+    }
+
+
+def _type_check_args(
+    func: ConfigKey, args: ConfigValue, parameters: typing.Dict[str, inspect.Parameter]
+):
+    # NOTE: Check the `args` type corresponds with the function signature.
+    frame = sys._getframe(1)
+    while frame.f_code.co_filename == __file__:
+        frame = frame.f_back
+    context = dict(globals=frame.f_globals, locals=frame.f_locals)
+
+    try:
+        type_hints = get_type_hints(func)
+    except NameError as e:
+        warnings.warn(
+            f"Skipping type check for `{func.__qualname__}` due to:\n{str(e)}", SkipTypeCheck
+        )
+        return
+
+    for key, value in args.items():
+        if key in parameters and key in type_hints:
+            try:
+                check_type(key, value, type_hints[key], **context)
+            except NameError as e:
+                warnings.warn(f"Skipping type check for `{key}` due to:\n{str(e)}", SkipTypeCheck)
 
 
 def _check_args(func: ConfigKey, args: ConfigValue):
     """Ensure every argument in `args` exists in `func`."""
     parameters = inspect.signature(func).parameters
 
-    # NOTE: Check the `args` type corresponds with the function signature.
-    frame = sys._getframe(1)
-    while frame.f_code.co_filename == __file__:
-        frame = frame.f_back
-    context = dict(globals=frame.f_globals, locals=frame.f_locals)
-    type_hints = get_type_hints(func)
-    for key, value in args.items():
-        if key in parameters and key in type_hints:
-            check_type(key, value, type_hints[key], **context)
+    _type_check_args(func, args, parameters)
 
     # NOTE: Check `args` exist in the function signature.
     if any(p.kind in (p.VAR_POSITIONAL, p.VAR_KEYWORD) for p in parameters.values()):
@@ -384,8 +411,10 @@ def add(config: Config, overwrite: bool = False):
 
     [_check_args(func, args) for func, args in config.items()]
 
-    for key, value in config.items():
-        key = _unwrap(key)
+    for key_, value in config.items():
+        key = _unwrap(key_)
+        if not _is_builtin(key):
+            setattr(key, _orginal_key, key_)
         _get_funcs(key)  # NOTE: Check `key` before adding it
         if key in _config:
             update = Args({**_config[key], **value})
@@ -437,9 +466,7 @@ def call(
     with warnings.catch_warnings():
         if _overwrite:
             warnings.filterwarnings(
-                "ignore",
-                module=r".*config.*",
-                message=f".*{_diff_args_message(func)}*",
+                "ignore", category=DiffArgsWarning, message=f".*{_diff_args_message(func)}*"
             )
         return partial(func)(*args, **kwargs)
 
